@@ -979,11 +979,6 @@ impl Transaction {
         }
     }
 
-    /// Verify the length of signatures matches the value in the message header
-    pub fn verify_signatures_len(&self) -> bool {
-        self.signatures.len() == self.message.header.num_required_signatures as usize
-    }
-
     /// Verify the transaction and hash its message.
     ///
     /// # Errors
